Twitter Bootstrap sources
=========================

Downloaded April 15th 2014 from
https://github.com/twbs/bootstrap-sass/tree/master/vendor/assets/stylesheets/bootstrap

Only _variables.scss changed to custom settings and Glyphicons removed in bootstrap.scss.
